package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.MallLinkIndustryCareer;

/**
 * 行业与职业关联Mapper接口
 *
 * @author LCL
 * @date 2023-10-20
 */
public interface MallLinkIndustryCareerMapper
{
    /**
     * 查询行业与职业关联
     *
     * @param linkId 行业与职业关联主键
     * @return 行业与职业关联
     */
    public MallLinkIndustryCareer selectMallLinkIndustryCareerByLinkId(Long linkId);

    /**
     * 查询行业与职业关联列表
     *
     * @param mallLinkIndustryCareer 行业与职业关联
     * @return 行业与职业关联集合
     */
    public List<MallLinkIndustryCareer> selectMallLinkIndustryCareerList(MallLinkIndustryCareer mallLinkIndustryCareer);

    /**
     * 新增行业与职业关联
     *
     * @param mallLinkIndustryCareer 行业与职业关联
     * @return 结果
     */
    public int insertMallLinkIndustryCareer(MallLinkIndustryCareer mallLinkIndustryCareer);

    /**
     * 修改行业与职业关联
     *
     * @param mallLinkIndustryCareer 行业与职业关联
     * @return 结果
     */
    public int updateMallLinkIndustryCareer(MallLinkIndustryCareer mallLinkIndustryCareer);

    /**
     * 删除行业与职业关联
     *
     * @param linkId 行业与职业关联主键
     * @return 结果
     */
    public int deleteMallLinkIndustryCareerByLinkId(Long linkId);

    /**
     * 批量删除行业与职业关联
     *
     * @param linkIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallLinkIndustryCareerByLinkIds(Long[] linkIds);

    /**
     * 根据行业ID删除行业与职业关联信息
     *
     * @param industryId 行业ID
     * @return 结果
     */
    public int deleteMallLinkIndustryCareerByIndustryId(Long industryId);

    /**
     * 批量新增行业与职业关联信息
     *
     * @param list 行业与职业关联列表
     * @return 结果
     */
    public int batchInsertMallLinkIndustryCareer(List<MallLinkIndustryCareer> list);
}
